@@ -4,7 +4,7 @@
  *
  * PHP Version 5
  *
- * Copyright (c) 2008-2013, Manuel Pichler <mapi@pdepend.org>.
+ * Copyright (c) 2008-2015, Manuel Pichler <mapi@pdepend.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,8 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @copyright 2008-2013 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
   */
 
 namespace PDepend\Source\Builder;
@@ -53,8 +53,8 @@ use PDepend\Util\Cache\CacheDriver;
 /**
  * Base interface for all code node builders.
  *
- * @copyright 2008-2013 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 interface Builder extends \IteratorAggregate
 {
@@ -919,12 +919,11 @@ interface Builder extends \IteratorAggregate
     /**
      * Builds a new primitive type node.
      *
-     * @param string $image The source image for the primitive type.
-     *
-     * @return \PDepend\Source\AST\ASTPrimitiveType
+     * @param string $image
+     * @return \PDepend\Source\AST\ASTScalarType
      * @since  0.9.6
      */
-    public function buildAstPrimitiveType($image);
+    public function buildAstScalarType($image);
 
     /**
      * Builds a new literal node.
