@@ -4,7 +4,7 @@
  *
  * PHP Version 5
  *
- * Copyright (c) 2008-2013, Manuel Pichler <mapi@pdepend.org>.
+ * Copyright (c) 2008-2015, Manuel Pichler <mapi@pdepend.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,8 +36,8 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @copyright 2008-2013 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 
 namespace PDepend\Source\Language\PHP;
@@ -47,20 +47,120 @@ use PDepend\Source\Tokenizer\Token;
 use PDepend\Source\Tokenizer\Tokenizer;
 use PDepend\Source\Tokenizer\Tokens;
 
+/**
+ * Define PHP 5.4 __TRAIT__ token constant.
+ */
+if (!defined('T_TRAIT_C')) {
+    define('T_TRAIT_C', 42000);
+}
+
+/**
+ * Define PHP 5.4 'trait' token constant.
+ */
+if (!defined('T_TRAIT')) {
+    define('T_TRAIT', 42001);
+}
+
+/**
+ * Define PHP 5.4 'insteadof' token constant.
+ */
+if (!defined('T_INSTEADOF')) {
+    define('T_INSTEADOF', 42002);
+}
+
+/**
+ * Define PHP 5.3 __NAMESPACE__ token constant.
+ */
+if (!defined('T_NS_C')) {
+    define('T_NS_C', 42003);
+}
+
+/**
+ * Define PHP 5.3 'use' token constant
+ */
+if (!defined('T_USE')) {
+    define('T_USE', 42004);
+}
+
+/**
+ * Define PHP 5.3 'namespace' token constant.
+ */
+if (!defined('T_NAMESPACE')) {
+    define('T_NAMESPACE', 42005);
+}
+
+/**
+ * Define PHP 5.6 '...' token constant
+ */
+if (!defined('T_ELLIPSIS')) {
+    define('T_ELLIPSIS', 42006);
+}
+
+/**
+ * Define PHP 5.3's '__DIR__' token constant.
+ */
+if (!defined('T_DIR')) {
+    define('T_DIR', 42006);
+}
+
+/**
+ * Define PHP 5.3's 'T_GOTO' token constant.
+ */
+if (!defined('T_GOTO')) {
+    define('T_GOTO', 42007);
+}
+
+/**
+ * Define PHP 5.4's 'T_CALLABLE' token constant
+ */
+if (!defined('T_CALLABLE')) {
+    define('T_CALLABLE', 42008);
+}
+
+/**
+ * Define PHP 5.5's 'T_YIELD' token constant
+ */
+if (!defined('T_YIELD')) {
+    define('T_YIELD', 42009);
+}
+
+/**
+ * Define PHP 5,5's 'T_FINALLY' token constant
+ */
+if (!defined('T_FINALLY')) {
+    define('T_FINALLY', 42010);
+}
+
+/**
+ * Define character token that was removed in PHP 7
+ */
+if (!defined('T_CHARACTER')) {
+    define('T_CHARACTER', 42011);
+}
+
+/**
+ * Define bad character token that was removed in PHP 7
+ */
+if (!defined('T_BAD_CHARACTER')) {
+    define('T_BAD_CHARACTER', 42012);
+}
+
+/**
+ * Define PHP 7's '<=>' token constant
+ */
+if (!defined('T_SPACESHIP')) {
+    define('T_SPACESHIP', 42013);
+}
+
 /**
  * This tokenizer uses the internal {@link token_get_all()} function as token stream
  * generator.
  *
- * @copyright 2008-2013 Manuel Pichler. All rights reserved.
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
+ * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class PHPTokenizerInternal implements Tokenizer
 {
-    /**
-     * Internally used transition token.
-     */
-    const T_ELLIPSIS = 23006;
-
     /**
      * Mapping between php internal tokens and php depend tokens.
      *
@@ -152,6 +252,7 @@ class PHPTokenizerInternal implements Tokenizer
         T_CLOSE_TAG                 =>  Tokens::T_CLOSE_TAG,
         T_INSTEADOF                 =>  Tokens::T_INSTEADOF,
         T_PROTECTED                 =>  Tokens::T_PROTECTED,
+        T_SPACESHIP                 =>  Tokens::T_SPACESHIP,
         T_CURLY_OPEN                =>  Tokens::T_CURLY_BRACE_OPEN,
         T_ENDFOREACH                =>  Tokens::T_ENDFOREACH,
         T_ENDDECLARE                =>  Tokens::T_ENDDECLARE,
@@ -197,6 +298,11 @@ class PHPTokenizerInternal implements Tokenizer
         //T_DOLLAR_OPEN_CURLY_BRACES  =>  Tokens::T_CURLY_BRACE_OPEN,
     );
 
+    /**
+     * Internally used transition token.
+     */
+    const T_ELLIPSIS = 23006;
+
     /**
      * Mapping between php internal text tokens an php depend numeric tokens.
      *
@@ -243,6 +349,7 @@ class PHPTokenizerInternal implements Tokenizer
         'yield'          =>  Tokens::T_YIELD,
         'parent'         =>  Tokens::T_PARENT,
         'finally'        =>  Tokens::T_FINALLY,
+        'callable'       =>  Tokens::T_CALLABLE,
         'insteadof'      =>  Tokens::T_INSTEADOF,
         'namespace'      =>  Tokens::T_NAMESPACE,
         '__dir__'        =>  Tokens::T_DIR,
@@ -335,24 +442,6 @@ class PHPTokenizerInternal implements Tokenizer
             Tokens::T_CONST            =>  Tokens::T_STRING,
             Tokens::T_FUNCTION         =>  Tokens::T_STRING,
         ),
-        Tokens::T_TRAIT_C=> array(
-            Tokens::T_OBJECT_OPERATOR  =>  Tokens::T_STRING,
-            Tokens::T_DOUBLE_COLON     =>  Tokens::T_STRING,
-            Tokens::T_CONST            =>  Tokens::T_STRING,
-            Tokens::T_FUNCTION         =>  Tokens::T_STRING,
-        ),
-        Tokens::T_TRAIT => array(
-            Tokens::T_OBJECT_OPERATOR  =>  Tokens::T_STRING,
-            Tokens::T_DOUBLE_COLON     =>  Tokens::T_STRING,
-            Tokens::T_CONST            =>  Tokens::T_STRING,
-            Tokens::T_FUNCTION         =>  Tokens::T_STRING,
-        ),
-        Tokens::T_INSTEADOF => array(
-            Tokens::T_OBJECT_OPERATOR  =>  Tokens::T_STRING,
-            Tokens::T_DOUBLE_COLON     =>  Tokens::T_STRING,
-            Tokens::T_CONST            =>  Tokens::T_STRING,
-            Tokens::T_FUNCTION         =>  Tokens::T_STRING,
-        ),
         Tokens::T_FINALLY => array(
             Tokens::T_OBJECT_OPERATOR  =>  Tokens::T_STRING,
             Tokens::T_DOUBLE_COLON     =>  Tokens::T_STRING,
@@ -368,11 +457,18 @@ class PHPTokenizerInternal implements Tokenizer
         Tokens::T_CONCAT => array(
             Tokens::T_CONCAT => array(
                 'type'  => self::T_ELLIPSIS,
-                'image' => '..'
+                'image' => '..',
             ),
             self::T_ELLIPSIS  =>  array(
                 'type'  => Tokens::T_ELLIPSIS,
-                'image' => '...'
+                'image' => '...',
+            )
+        ),
+
+        Tokens::T_ANGLE_BRACKET_CLOSE => array(
+            Tokens::T_IS_SMALLER_OR_EQUAL => array(
+                'type'  => Tokens::T_SPACESHIP,
+                'image' => '<=>',
             )
         ),
     );
